@@ -28,6 +28,11 @@
 #include <glibmm_generate_extra_defs/generate_extra_defs.h>
 #include <gdk/gdk.h>
 #include <gtk/gtk.h>
+
+#ifdef GDK_WINDOWING_X11
+#include <gtk/gtkx.h>
+#endif
+
 #ifndef G_OS_WIN32
 # include <gtk/gtkunixprint.h>
 #endif
@@ -41,10 +46,10 @@ int main(int argc, char** argv)
 #if !defined(G_OS_WIN32)
             << get_defs( GDK_TYPE_DISPLAY_MANAGER )
 #endif /* G_OS_WIN32 */
-            << get_defs( GDK_TYPE_DRAWABLE )
             << get_defs( GDK_TYPE_PIXBUF )
             << get_defs( GDK_TYPE_PIXBUF_ANIMATION )
             << get_defs( GDK_TYPE_PIXBUF_LOADER )
+            << get_defs( GDK_TYPE_RGBA )
             << get_defs( GDK_TYPE_SCREEN )
             << get_defs( GDK_TYPE_VISUAL )
             << get_defs( GDK_TYPE_WINDOW )
@@ -62,6 +67,7 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_ASPECT_FRAME )
             << get_defs( GTK_TYPE_ASSISTANT )
             << get_defs( GTK_TYPE_BIN )
+            << get_defs( GTK_TYPE_BORDER )
             << get_defs( GTK_TYPE_BOX )
             << get_defs( GTK_TYPE_BUILDER )
             << get_defs( GTK_TYPE_BUTTON )
@@ -69,6 +75,9 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_CALENDAR )
             << get_defs( GTK_TYPE_CHECK_BUTTON )
             << get_defs( GTK_TYPE_CHECK_MENU_ITEM )
+            << get_defs( GTK_TYPE_CELL_AREA )
+            << get_defs( GTK_TYPE_CELL_AREA_BOX )
+            << get_defs( GTK_TYPE_CELL_AREA_CONTEXT )
             << get_defs( GTK_TYPE_CELL_EDITABLE )
             << get_defs( GTK_TYPE_CELL_LAYOUT )
             << get_defs( GTK_TYPE_CELL_RENDERER )
@@ -86,7 +95,6 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_COLOR_SELECTION )
             << get_defs( GTK_TYPE_COLOR_SELECTION_DIALOG )
             << get_defs( GTK_TYPE_COMBO_BOX )
-            << get_defs( GTK_TYPE_COMBO_BOX_ENTRY )
             << get_defs( GTK_TYPE_CONTAINER )
             << get_defs( GTK_TYPE_CELL_VIEW )
             << get_defs( GTK_TYPE_DIALOG )
@@ -107,6 +115,7 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_FONT_SELECTION )
             << get_defs( GTK_TYPE_FONT_SELECTION_DIALOG )
             << get_defs( GTK_TYPE_FRAME )
+            << get_defs( GTK_TYPE_GRID )
             << get_defs( GTK_TYPE_HANDLE_BOX )
             << get_defs( GTK_TYPE_ICON_THEME )
             << get_defs( GTK_TYPE_IMAGE )
@@ -125,11 +134,14 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_MESSAGE_DIALOG )
             << get_defs( GTK_TYPE_MISC )
             << get_defs( GTK_TYPE_NOTEBOOK )
+            << get_defs( GTK_TYPE_NUMERABLE_ICON )
             << get_defs( GTK_TYPE_OFFSCREEN_WINDOW )
             << get_defs( GTK_TYPE_ORIENTABLE )
             << get_defs( GTK_TYPE_PANED )
-#if !defined(G_OS_WIN32)
+#ifdef GDK_WINDOWING_X11
             << get_defs( GTK_TYPE_PLUG )
+#endif
+#if !defined(G_OS_WIN32) 
             << get_defs( GTK_TYPE_PRINTER )
             << get_defs( GTK_TYPE_PRINT_JOB )
 #endif /* G_OS_WIN32 */
@@ -153,23 +165,25 @@ int main(int argc, char** argv)
             << get_defs( GTK_TYPE_RECENT_CHOOSER_WIDGET )
             << get_defs( GTK_TYPE_RECENT_FILTER )
             << get_defs( GTK_TYPE_RECENT_MANAGER )
-            << get_defs( GTK_TYPE_RULER )
             << get_defs( GTK_TYPE_SCALE )
             << get_defs( GTK_TYPE_SCALE_BUTTON )
+            << get_defs( GTK_TYPE_SCROLLABLE )
             << get_defs( GTK_TYPE_SCROLLBAR )
             << get_defs( GTK_TYPE_SCROLLED_WINDOW )
             << get_defs( GTK_TYPE_SEPARATOR )
             << get_defs( GTK_TYPE_SEPARATOR_TOOL_ITEM )
             << get_defs( GTK_TYPE_SETTINGS )
             << get_defs( GTK_TYPE_SIZE_GROUP )
-#if !defined(G_OS_WIN32)
+#ifdef GDK_WINDOWING_X11
             << get_defs( GTK_TYPE_SOCKET )
-#endif /* G_OS_WIN32 */
+#endif
             << get_defs( GTK_TYPE_SPINNER )
             << get_defs( GTK_TYPE_SPIN_BUTTON )
             << get_defs( GTK_TYPE_STATUSBAR )
             << get_defs( GTK_TYPE_STATUS_ICON )
-            << get_defs( GTK_TYPE_STYLE )
+            << get_defs( GTK_TYPE_STYLE_CONTEXT )
+            << get_defs( GTK_TYPE_STYLE_PROVIDER )
+            << get_defs( GTK_TYPE_SWITCH )
             << get_defs( GTK_TYPE_TABLE )
             << get_defs( GTK_TYPE_TEAROFF_MENU_ITEM )
             << get_defs( GTK_TYPE_TOGGLE_BUTTON )
